@@ -253,7 +253,7 @@ t.test('more static method coverage', async t => {
   t.equal(Body.getTotalBytes({ body: {} }), null)
 })
 
-t.test('json', async t => {
+t.test('json FetchError', async t => {
   t.same(await new Body('{"a":1}').json(), { a: 1 })
   await t.rejects(Object.assign(new Body('a=1'), { url: 'asdf' }).json(), {
     name: 'FetchError',
@@ -263,6 +263,18 @@ t.test('json', async t => {
   })
 })
 
+t.test('json body error', async t => {
+  const s = new PassThrough()
+  const b = new Body(s)
+  b.url = 'xyz'
+  setTimeout(() => s.emit('error', new RangeError('hello')))
+  await t.rejects(b.json(), {
+    name: 'FetchError',
+    message: 'Could not create Buffer from response body for xyz: hello',
+    type: 'system',
+  })
+})
+
 t.test('handles environments where setTimeout does not have unref', async t => {
   const originalSetTimeout = setTimeout
   // simulate environments without unref()
