@@ -1,11 +1,7 @@
 const http = require('http')
 const zlib = require('minizlib')
 const { multipart: Multipart } = require('parted')
-
-let convert
-try {
-  convert = require('encoding').convert
-} catch (e) {}
+const convert = require('encoding').convert
 
 class TestServer {
   constructor () {
@@ -65,6 +61,7 @@ class TestServer {
       res.statusCode = 200
       res.setHeader('Content-Type', 'text/plain')
       res.setHeader('Content-Encoding', 'gzip')
+      // eslint-disable-next-line promise/catch-or-return
       new zlib.Gzip().end('hello world').concat().then(buf => res.end(buf))
     }
 
@@ -72,6 +69,7 @@ class TestServer {
       res.statusCode = 200
       res.setHeader('Content-Type', 'text/plain')
       res.setHeader('Content-Encoding', 'gzip')
+      // eslint-disable-next-line promise/catch-or-return
       new zlib.Gzip().end('hello world').concat().then(buf =>
         res.end(buf.slice(0, buf.length - 8)))
     }
@@ -80,6 +78,7 @@ class TestServer {
       res.statusCode = 200
       res.setHeader('Content-Type', 'text/plain')
       res.setHeader('Content-Encoding', 'deflate')
+      // eslint-disable-next-line promise/catch-or-return
       new zlib.Deflate().end('hello world').concat().then(buf => res.end(buf))
     }
 
@@ -100,6 +99,7 @@ class TestServer {
       res.statusCode = 200
       res.setHeader('Content-Type', 'text/plain')
       res.setHeader('Content-Encoding', 'deflate')
+      // eslint-disable-next-line promise/catch-or-return
       new zlib.DeflateRaw().end('hello world').concat().then(buf => res.end(buf))
     }
 
